local WIDTH  = 800																				-- screen constant
local HEIGHT = 600																				-- screen constant

local audience																						-- robot struct
local sfx_walk																						-- movement sfx

local isLasering, isWarping                           		-- do important things



function love.load()

	love.graphics.setMode(WIDTH, HEIGHT, false, true)				-- no fullscreen, vsync
	love.graphics.setCaption("CHANNEL 59")									-- our title CHANNEL 59

	audience = {}																						-- our friendly bot
	audience.image = love.graphics.newImage('audience.png')	-- front-facing png
	audience.x   = WIDTH/2																	-- position in x
	audience.y   = 0																				-- position in y
	audience.dx  = 10																				-- x-axis dist/frame
	audience.dy  = 10																				-- y-axis dist/frame
	audience.draw = function() 															-- draw self
										love.graphics.draw(audience.image, audience.x, audience.y)
									end

	local sfx = love.audio.newSource('audience_born.wav')		-- load spawn sound
	sfx:play()																							-- play spawn sound

	sfx_walk = love.audio.newSource('audience_walk.wav')		-- load walk sound
	sfx_beam = love.audio.newSource('audience_beam.wav')  	-- load laser sound
	sfx_warp = love.audio.newSource('audience_warp.wav')		-- load warp sound

end



function love.draw()

	love.graphics.setColor(255, 255, 255)										-- set color to white
	audience.draw()																					-- robot draws itself

	if isLasering == true then															-- lots of little squares
		DrawLaser()
		isLasering = false																		-- no more
	end

	if isWarping == true then
		DrawWarp()
		isWarping = false
	end

end



function love.update(dt)

	if dt < 1/30 then																				-- lock framerate to 30
		love.timer.sleep(1/30 - dt)														-- by idling on 33ms lines
	end

end



function love.keypressed(key)

	if key == 'w' then
		audience.y = audience.y - audience.dy									-- move up
		sfx_walk:stop()
		sfx_walk:play()																				-- to robot noise
	end

	if key == 'a' then
		audience.x = audience.x - audience.dx									-- move left
		sfx_walk:stop()
		sfx_walk:play()																				-- with robot noise
	end	

	if key == 's' then
		audience.y = audience.y + audience.dy									-- move down 
		sfx_walk:stop()
		sfx_walk:play()																				-- robot noise
	end

	if key == 'd' then
		audience.x = audience.x + audience.dx									-- move right
		sfx_walk:stop()
		sfx_walk:play()																				-- gotta have robot noise
	end

	if key == 'j' then
		isLasering = true																			-- set flag to draw lasers																			
		sfx_beam:stop()																				-- play other robot noises
		sfx_beam:play()
	end

	if key == 'k' then
		isWarping  = true
		audience.x = math.random(WIDTH)												-- randomly warp on screen
		audience.y = math.random(HEIGHT)											-- to absolutely anywhere
		sfx_warp:stop()																				-- as long as there are
		sfx_warp:play()																				-- cool robot noises
	end
	
	if key == 'escape' then
		love.event.push('quit')																-- quit game
	end

end













function DrawWarp()

	for i = 1, 100 do																				-- draw a hundred colored rectangles

		love.graphics.setColor(math.random(255), math.random(255), math.random(255))
		love.graphics.setLineWidth(math.random(25))
		love.graphics.rectangle('line', math.random(WIDTH), math.random(HEIGHT), math.random(10), math.random(15))
	end

end


function DrawLaser()

	love.graphics.setColor(0, 0, 255, 255)												-- leftmost eye (1/4)
	love.graphics.setLineWidth(1)
	love.graphics.line(audience.x+12, audience.y+3, audience.x, HEIGHT)

	love.graphics.setColor(100, 0, 255, 255)											-- middle left eye (2/4)
	love.graphics.setLineWidth(1)
	love.graphics.line(audience.x+13, audience.y+3, audience.x, HEIGHT)

	love.graphics.setColor(255, 0, 255, 255)												-- middle right eye (3/4)
	love.graphics.setLineWidth(1)
	love.graphics.line(audience.x+14, audience.y+3, audience.x, HEIGHT)

	love.graphics.setColor(255, 0, 0, 255)												-- rightmost eye (4/4)
	love.graphics.setLineWidth(1)
	love.graphics.line(audience.x+15, audience.y+3, audience.x, HEIGHT)

end
